// Generally enable the »directors« feature. To actually cause SWIG to emit
// the polymorphy glue code, you need to use %feature("director") as shown
// below.
%module(directors="1") demo;

// Enable cross-language polymorphy for the Shape class. For testing purposes,
// you could also enable them globally by passing »-directors« at the command
// line, but since they come with a certain overhead, you normally do not want
// to do this.
%feature("director") Shape;

// Include the SWIG definitions for nicely wrapping the used STL classes.
%include <std_pair.i>
%include <std_string.i>

// Tell SWIG to instanciate std::pair for two floats, naming the proxy class
// »Position«. Unfortunately, there is no really good way to automate this.
%template(Position) std::pair<float, float>;


// Instead of manually specifying the interface we want to use (this is also 
// possible, e.g. if SWIG should choke on some weird constructs or if you want
// to expose only a small part of the interface to the target language), we
// just include the header file here.

// The code between %{ and %} is written to the wrapper C++ file, where the
// include is needed too.
%{
#include "demo.h"
%}

// The %include command causes SWIG to actually process the declarations from
// »demo.h«.
%include "demo.h"
